@@ -1,8 +1,8 @@
-/* $Id: dnscache.h,v 1.5 1999/11/17 05:15:44 rjkaes Exp $
+/* $Id: dnscache.h,v 1.7 2001/10/25 17:02:50 rjkaes Exp $
  *
  * See 'dnscache.c' for a detailed description.
  *
- * Copyright (C) 1999  Robert James Kaes (rjkaes@flarenet.com
+ * Copyright (C) 1999  Robert James Kaes (rjkaes@flarenet.com)
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -15,20 +15,11 @@
  * General Public License for more details.
  */
 
-#ifndef _DNSCACHE_H_
-#define _DNSCACHE_H_	1
+#ifndef _TINYPROXY_DNSCACHE_H_
+#define _TINYPROXY_DNSCACHE_H_
 
-#ifdef HAVE_CONFIG_H
-#include <defines.h>
-#endif
-
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
-#define DNS_GARBAGE_COL	100
+#include "tinyproxy.h"
 
 extern int dnscache(struct in_addr *addr, char *domain);
-extern void dnsclean(void);
 
 #endif
