@@ -1,4 +1,4 @@
-/* $Id: sock.h,v 1.9 1999/10/29 16:29:51 rjkaes Exp $
+/* $Id: sock.h,v 1.6 2001/10/25 17:02:50 rjkaes Exp $
  *
  * See 'sock.c' for a detailed description.
  *
@@ -16,24 +16,28 @@
  * General Public License for more details.
  */
 
-#ifndef _SOCK_H_
-#define _SOCK_H_	1
+#ifndef TINYPROXY_SOCK_H
+#define TINYPROXY_SOCK_H
 
-#include "buffer.h"
+#include "tinyproxy.h"
 
 #define PEER_IP_LENGTH		16
 #define PEER_STRING_LENGTH	256
 
-extern int setup_fd;
+#define MAXLINE (1024 * 4)
 
-extern int opensock(char *ip_addr, int port);
-extern int init_listen_sock(int port);
-extern int listen_sock(void);
-extern void de_init_listen_sock(void);
-extern int setsocketopt(int *sock_fd, int options, int flip);
+extern int opensock(char *ip_addr, uint16_t port);
+extern int listen_sock(uint16_t port, socklen_t *addrlen);
+
+extern int socket_nonblocking(int sock);
+extern int socket_blocking(int sock);
 
 extern char *getpeer_ip(int fd, char *ipaddr);
 extern char *getpeer_string(int fd, char *string);
-extern int readline(int fd, struct buffer_s *buffer, char **line);
+
+extern ssize_t safe_write(int fd, const void *buffer, size_t count);
+extern ssize_t safe_read(int fd, void *buffer, size_t count);
+
+extern ssize_t readline(int fd, char *ptr, size_t maxlen);
 
 #endif
